@@ -76,7 +76,6 @@ from schooltool.table.table import label_cell_formatter_factory
 from schooltool.table.table import ImageInputColumn
 from schooltool.table.interfaces import ITableFormatter
 from schooltool.skin.skin import OrderedViewletManager
-from schooltool.skin.breadcrumbs import CustomNameBreadCrumbInfo
 from schooltool.skin import flourish
 from schooltool.skin.flourish.form import Form
 from schooltool.skin.flourish.form import Dialog
@@ -984,9 +983,6 @@ class ViewRobot(BrowserPage):
         return "User-agent: *\nDisallow: /"
 
 
-SchoolBreadcrumbInfo = CustomNameBreadCrumbInfo('school')
-
-
 @adapter(ISchoolToolApplication)
 @implementer(ISchoolToolAuthenticationPlugin)
 def getAuthentication(app):
