@@ -54,7 +54,6 @@ from zope.browsermenu.interfaces import IBrowserMenu
 from zope.publisher.interfaces.browser import IBrowserView
 
 from schooltool.relationship.tests import setUpRelationships
-from schooltool.skin import breadcrumbs
 from schooltool.skin.macros import SchoolToolMacros
 
 from schooltool.app.browser import SchoolToolAPI, SortBy
@@ -160,7 +159,9 @@ def setUp(test=None):
     # resources
     class ResourceStub:
         def __init__(self, request):
-            pass
+            self.request = request
+        def __getitem__(self, key):
+            return ResourceStub(self.request)
         def __call__(self):
             return "a dummy resource"
 
@@ -168,8 +169,6 @@ def setUp(test=None):
                  'next.png', 'prev.png', 'favicon.ico',
                  'calwidget-calendar.js', 'calwidget-calendar.css',
                  'calwidget-icon.gif', 'print.css', 'jquery.js',
-                 'zonki-angry.png', 'zonki-pointing.png',
-                 'zonki-question.png', 'zonki-reading.png',
                  'zonki-regular.png']:
         ztapi.browserResource(name, ResourceStub)
 
@@ -178,16 +177,6 @@ def setUp(test=None):
     provideUtility(BrowserMenuStub('schooltool_actions'), IBrowserMenu,
                    'schooltool_actions')
 
-    # breadcrumbs
-    provideAdapter(
-        breadcrumbs.Breadcrumbs,
-        (Interface, IDefaultBrowserLayer),
-        Interface,
-        name='breadcrumbs')
-
-    provideAdapter(
-        breadcrumbs.GenericBreadcrumbInfo)
-
     # `provider` TALES namespaces
     from zope.browserpage import metaconfigure
     from zope.contentprovider import tales
