@@ -375,6 +375,7 @@ def doctest_setup():
 class ConfigStub(object):
 
     devmode = False
+    site_definition = None
 
 
 class OptionsStub(object):
@@ -392,8 +393,9 @@ def doctest_bootstrapSchoolTool():
 
         >>> from schooltool.app.main import SchoolToolServer
         >>> server = SchoolToolServer()
-        >>> server.siteConfigFile = ftesting_zcml
-        >>> server.configure(OptionsStub())
+        >>> options = OptionsStub()
+        >>> options.config.site_definition = ftesting_zcml
+        >>> server.configureComponents(options)
 
     When we start with an empty database, bootstrapSchoolTool creates a
     SchoolTool application in it.
@@ -469,8 +471,9 @@ def doctest_restoreManagerUser():
 
         >>> from schooltool.app.main import SchoolToolServer
         >>> server = SchoolToolServer()
-        >>> server.siteConfigFile = ftesting_zcml
-        >>> server.configure(OptionsStub())
+        >>> options = OptionsStub()
+        >>> options.config.site_definition = ftesting_zcml
+        >>> server.configureComponents(options)
 
     We also need an application (we are doing the full set up in here
     because else person factory local utility is not being
