@@ -69,7 +69,7 @@ from schooltool.course.section import Section
 from schooltool.course.section import copySection
 from schooltool.course.browser.course import CoursesActiveTabMixin as SectionsActiveTabMixin
 from schooltool.person.interfaces import IPerson
-from schooltool.report.browser.report import RequestReportDownloadDialog
+from schooltool.report.browser.report import RequestRemoteReportDialog
 from schooltool.resource.browser.resource import EditLocationRelationships
 from schooltool.resource.browser.resource import EditEquipmentRelationships
 from schooltool.resource.interfaces import ILocation, IEquipment
@@ -1821,17 +1821,17 @@ class SectionsYearNavBreadcrumbs(SchoolyearNavBreadcrumbs):
     title = _('Sections')
 
 
-class FlourishRequestSectionRosterView(RequestReportDownloadDialog):
-
-    def nextURL(self):
-        return '%s/section_roster.pdf' % absoluteURL(self.context,
-                                                     self.request)
-
-
 class SectionRosterPDFView(flourish.report.PlainPDFPage):
 
     name = _("Section Roster")
 
+    content_template = flourish.templates.XMLFile('rml/section_roster.pt')
+
+    @property
+    def message_title(self):
+        return _("section ${title} roster",
+                 mapping={'title': self.context.title})
+
     def formatDate(self, date, format='mediumDate'):
         if date is None:
             return ''
@@ -1889,3 +1889,8 @@ class SectionRosterPDFView(flourish.report.PlainPDFPage):
         return '%s, %s %s' % (person.last_name,
                               person.first_name,
                               person.middle_name or '')
+
+
+class FlourishRequestSectionRosterView(RequestRemoteReportDialog):
+
+    report_builder = SectionRosterPDFView
