@@ -29,6 +29,14 @@ def get_available_types():
 available_types = get_available_types()
 
 
+def get_paste_parts():
+    paste_part_factories = list(pkg_resources.iter_entry_points(
+            'schooltool.paste_configuration'))
+    return [entry.load() for entry in paste_part_factories]
+
+paste_configurers = get_paste_parts()
+
+
 class SchoolToolDeploy(Template):
     _template_dir = 'schooltool_template'
     summary = "(Paste) deployment of a SchoolTool application"
@@ -51,6 +59,10 @@ class SchoolToolDeploy(Template):
             vars.get('data_dir', os.path.join(vars['project'], 'var')))
         vars['run_dir'] = os.path.abspath(
             vars.get('run_dir', os.path.join(vars['project'], 'run')))
+        vars['paste_extra_paths'] = ''
+        vars['paste_extra_parts'] = ''
+        for factory in paste_configurers:
+            factory(vars)
         return vars
 
     def write_files(self, command, output_dir, vars):
